@@ -1,22 +1,19 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
-
 /* gstreamermm - a C++ wrapper for gstreamer
  *
  * Copyright 2008 The gstreamermm Development Team
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #ifndef _PLAYERWINDOW_H
@@ -31,8 +28,8 @@
 #include <gstreamermm/element.h>
 #include <gstreamermm/pipeline.h>
 #include <gstreamermm/bus.h>
-#include <gstreamerbasemm/playbin2.h>
-#include <gstreamerbasemm/ximagesink.h>
+#include <gstreamermm/playbin2.h>
+#include <gstreamermm/ximagesink.h>
 
 class PlayerWindow : public Gtk::Window
 {
@@ -41,12 +38,13 @@ public:
    * @param playbin The pipeline that can play media files.
    * @param video_sink The video sink to use to display stream video (if any).
    */
-  PlayerWindow(const Glib::RefPtr<GstBase::PlayBin2>& playbin, const Glib::RefPtr<GstBase::XImageSink>& video_sink);
+  PlayerWindow(const Glib::RefPtr<Gst::PlayBin2>& playbin, const Glib::RefPtr<Gst::XImageSink>& video_sink);
   virtual ~PlayerWindow();
 
 protected:
 
   //Signal handlers:
+  void on_video_area_realize();
   void on_bus_message_sync(const Glib::RefPtr<Gst::Message>& message);
   bool on_bus_message(const Glib::RefPtr<Gst::Bus>& bus, const Glib::RefPtr<Gst::Message>& message);
   bool on_video_pad_got_buffer(const Glib::RefPtr<Gst::Pad>& pad, const Glib::RefPtr<Gst::MiniObject>& buffer);
@@ -75,11 +73,12 @@ protected:
   Gtk::Button m_forward_button;
   Gtk::Button m_open_button;
 
-  Glib::RefPtr<GstBase::PlayBin2> m_play_bin;
-  Glib::RefPtr<GstBase::XImageSink> m_video_sink;
+  Glib::RefPtr<Gst::PlayBin2> m_play_bin;
+  Glib::RefPtr<Gst::XImageSink> m_video_sink;
   sigc::connection m_timeout_connection;
   guint m_watch_id;
   gint64 m_duration;
+  gulong m_x_window_id;
   gulong m_pad_probe_id;
 };
 
