@@ -1,28 +1,28 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 2 -*-
-
 /* gstreamermm - a C++ wrapper for gstreamer
  *
  * Copyright 2008 The gstreamermm Development Team
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include <gstreamermm.h>
 #include <iostream>
 #include <iomanip>
 
+namespace
+{
+
 Glib::RefPtr<Glib::MainLoop> mainloop;
 Glib::RefPtr<Gst::Pipeline> pipeline;
 Glib::RefPtr<Gst::Element> decoder;
@@ -36,7 +36,7 @@ bool on_timeout()
 
   Glib::RefPtr<Gst::Query> query = Gst::QueryPosition::create(fmt);
 
-  if (pipeline->query(query)
+  if(pipeline->query(query)
     && pipeline->query_duration(fmt, len))
   {
     // Cast query's RefPtr to RefPtr<Gst::QueryPosition> to parse the
@@ -66,7 +66,7 @@ bool on_timeout()
 // This function is used to receive asynchronous messages in the main loop.
 bool on_bus_message(const Glib::RefPtr<Gst::Bus>& /* bus */, const Glib::RefPtr<Gst::Message>& message)
 {
-  switch (message->get_message_type()) {
+  switch(message->get_message_type()) {
     case Gst::MESSAGE_EOS:
       std::cout << std::endl << "End of stream" << std::endl;
       mainloop->quit();
@@ -101,19 +101,17 @@ void on_parser_pad_added(const Glib::RefPtr<Gst::Pad>& newPad)
   // We can now link this pad with the audio decoder
   std::cout << "Dynamic pad created. Linking parser/decoder." << std::endl;
   Glib::RefPtr<Gst::Pad> sinkPad = decoder->get_static_pad("sink");
+  Gst::PadLinkReturn ret = newPad->link(sinkPad);
 
-  try
+  if (ret != Gst::PAD_LINK_OK && ret != Gst::PAD_LINK_WAS_LINKED)
   {
-    newPad->link(sinkPad);
-  }
-  catch(const std::runtime_error& ex)
-  {
-    std::cerr << "Exception caught while linking: " << ex.what() << std::endl;
+    std::cerr << "Linking of pads " << newPad->get_name() << " and " <<
+      sinkPad->get_name() << " failed." << std::endl;
   }
 }
 
 bool on_sink_pad_have_data(const Glib::RefPtr<Gst::Pad>& pad,
-        const Glib::RefPtr<Gst::MiniObject>& data)
+                           const Glib::RefPtr<Gst::MiniObject>&)
 {
   std::cout << "Sink pad '" << pad->get_name() << "' has received data;";
   std::cout << " will now remove sink data probe id: " << data_probe_id << std::endl;
@@ -121,20 +119,22 @@ bool on_sink_pad_have_data(const Glib::RefPtr<Gst::Pad>& pad,
   return true;
 }
 
-int main(int argc, char* argv[])
+} // anonymous namespace
+
+int main(int argc, char** argv)
 {
+  // Initialize Gstreamermm:
+  Gst::init(argc, argv);
+
   // Check input arguments:
-  if (argc < 2)
+  if(argc < 2)
   {
     std::cout << "Usage: " << argv[0] << " <Ogg/Vorbis filename>" << std::endl;
-    return -1;
+    return 1;
   }
 
   const std::string filename = argv[1];
 
-  // Initialize Gstreamermm:
-  Gst::init(argc, argv);
-
   mainloop = Glib::MainLoop::create();
 
   // Create the pipeline:
@@ -168,10 +168,10 @@ int main(int argc, char* argv[])
     std::cerr << "alsasink element could not be created." << std::endl;
 
   //Check that the elements were created:
-  if (!pipeline || !source || !parser || !decoder || !conv || !sink)
+  if(!pipeline || !source || !parser || !decoder || !conv || !sink)
   {
     std::cerr << "One element could not be created" << std::endl;
-    return -1;
+    return 1;
   }
 
   Glib::RefPtr<Gst::Pad> pad = sink->get_static_pad("sink");
@@ -179,12 +179,9 @@ int main(int argc, char* argv[])
     data_probe_id = pad->add_data_probe( sigc::ptr_fun(&on_sink_pad_have_data) );
   //std::cout << "sink data probe id = " << data_probe_id << std::endl;
 
-
-  // Set the filename property on the file source.
-  // TODO: Create a FileSrc class that we can dynamic_cast<> to, so we can use property_location()?
   source->set_property("location", filename);
 
-  // Get the bus from the pipeline, 
+  // Get the bus from the pipeline,
   // and add a bus watch to the default main context with the default priority:
   Glib::RefPtr<Gst::Bus> bus = pipeline->get_bus();
   bus->add_watch( sigc::ptr_fun(&on_bus_message) );
@@ -198,16 +195,15 @@ int main(int argc, char* argv[])
   catch(const Glib::Error& ex)
   {
     std::cerr << "Error while adding elements to the pipeline: " << ex.what() << std::endl;
-    return -1;
+    return 1;
   }
 
-
   // Link the elements together:
   try
   {
     source->link(parser);
 
-    // We cannot link the parser and decoder yet, 
+    // We cannot link the parser and decoder yet,
     // because the parser uses dynamic pads.
     // So we do it later in a pad-added signal handler:
     parser->signal_pad_added().connect( sigc::ptr_fun(&on_parser_pad_added) );
@@ -219,7 +215,6 @@ int main(int argc, char* argv[])
     std::cout << "Exception while linking elements: " << ex.what() << std::endl;
   }
 
-
   // Call on_timeout function at a 200ms
   // interval to regularly print the position of the stream
   Glib::signal_timeout().connect(sigc::ptr_fun(&on_timeout), 200);
