@@ -23,6 +23,7 @@
 #include "basetransform.h"
 #include "bin.h"
 #include "buffer.h"
+#include "bufferlist.h"
 #include "bus.h"
 #include "caps.h"
 #include "cddabasesrc.h"
@@ -145,6 +146,7 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType gst_buffer_get_type(void);
+GType gst_buffer_list_get_type(void);
 GType gst_event_get_type(void);
 GType gst_message_get_type(void);
 GType gst_query_get_type(void);
@@ -157,6 +159,7 @@ GType gst_query_get_type(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Gst {  class Buffer_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
+namespace Gst {  class BufferList_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
 namespace Gst {  class Event_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
 namespace Gst {  class Message_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
 namespace Gst {  class Query_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
@@ -168,12 +171,14 @@ void gst_wrap_init()
 
 // Map gtypes to gstreamermm wrapper-creation functions:
   Gst::wrap_register(gst_buffer_get_type(), &Gst::Buffer_Class::wrap_new);
+  Gst::wrap_register(gst_buffer_list_get_type(), &Gst::BufferList_Class::wrap_new);
   Gst::wrap_register(gst_event_get_type(), &Gst::Event_Class::wrap_new);
   Gst::wrap_register(gst_message_get_type(), &Gst::Message_Class::wrap_new);
   Gst::wrap_register(gst_query_get_type(), &Gst::Query_Class::wrap_new);
 
   // Register the gtkmm gtypes:
   Gst::Buffer::get_type();
+  Gst::BufferList::get_type();
   Gst::Event::get_type();
   Gst::Message::get_type();
   Gst::Query::get_type();
