@@ -359,12 +359,12 @@ namespace Gst {
 void wrap_init()
 {
   // Register Error domains:
-  Glib::Error::register_domain(gst_core_error_quark(), &Gst::CoreError::throw_func);
-  Glib::Error::register_domain(gst_library_error_quark(), &Gst::LibraryError::throw_func);
-  Glib::Error::register_domain(gst_parse_error_quark(), &Gst::ParseError::throw_func);
-  Glib::Error::register_domain(gst_plugin_error_quark(), &Gst::PluginError::throw_func);
-  Glib::Error::register_domain(gst_resource_error_quark(), &Gst::ResourceError::throw_func);
-  Glib::Error::register_domain(gst_stream_error_quark(), &Gst::StreamError::throw_func);
+  Glib::Error::register_domain(gst_core_error_quark(), &::Gst::CoreError::throw_func);
+  Glib::Error::register_domain(gst_library_error_quark(), &::Gst::LibraryError::throw_func);
+  Glib::Error::register_domain(gst_parse_error_quark(), &::Gst::ParseError::throw_func);
+  Glib::Error::register_domain(gst_plugin_error_quark(), &::Gst::PluginError::throw_func);
+  Glib::Error::register_domain(gst_resource_error_quark(), &::Gst::ResourceError::throw_func);
+  Glib::Error::register_domain(gst_stream_error_quark(), &::Gst::StreamError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(gst_adder_get_type(), &Gst::Adder_Class::wrap_new);
